#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-gen
version:              0.3.0.1
visibility:           public
id:                   monad-gen-0.3.0.1-2WsHS6UvzUV8rlBBBSUuyA
key:                  monad-gen-0.3.0.1-2WsHS6UvzUV8rlBBBSUuyA
license:              MIT
maintainer:           danny.gratzer@gmail.com
author:               Danny Gratzer
synopsis:             A simple monad for generating fresh integers
description:
    This module provides a simple monad transformer @GenT@ to enumerate unique values within
    a monadic computation. It also plays nicely with everything in the MTL.

category:             Utility
abi:                  419154b3f6bbaea35623186f36fc2290
exposed:              True
exposed-modules:      Control.Monad.Gen Control.Monad.Gen.Class
import-dirs:          /usr/lib/ghc-8.10.5/site-local/monad-gen-0.3.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/monad-gen-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/monad-gen-0.3.0.1
hs-libraries:         HSmonad-gen-0.3.0.1-2WsHS6UvzUV8rlBBBSUuyA
depends:              base-4.14.2.0 mtl-2.2.2 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-monad-gen/html/monad-gen.haddock
haddock-html:         /usr/share/doc/haskell-monad-gen/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

